@@ -3,15 +3,18 @@
   date <- date()
   x <- regexpr("[0-9]{4}", date)
   this.year <- substr(date, x[1], x[1] + attr(x, "match.length") - 1)
-
+  
   # Retrieve Current Version
   this.version = packageVersion("ROptSpace")
-
+  
   ## Print on Screen
+  packageStartupMessage("**--------------------------------------------------------**")
   packageStartupMessage("** ROptSpace")
   packageStartupMessage("**  - Matrix Reconstruction from a Few Entries")
+  packageStartupMessage("**")
   packageStartupMessage("** Version    : ",this.version,"      (",this.year,")",sep="")
-  packageStartupMessage("** Maintainer : Kisung You (ksyou496@gmail.com)")
+  packageStartupMessage("** Maintainer : Kisung You (kyoustat@gmail.com)")
   packageStartupMessage("**")
   packageStartupMessage("** Please share any bugs or suggestions to the maintainer.")
-}
+  packageStartupMessage("**--------------------------------------------------------**")
+}
\ No newline at end of file
